#include <iostream>
#include <vector>
#include <map>
#include <utility>
#include <tuple>
#include <queue>
#include <cmath>
#define vi vector<int>
#define pb push_back
using ll = long long;
using namespace std;
using Point = std::pair<int,int>;

// ---------------------------
// copied from TUM cheat sheet
struct dinic {
	struct edge {
		ll j, c, f;
	};

	const ll flow_inf = 1e18;
	vector<edge> e;
	vector<vector<int>> adj;
	vector<int> lvl, ptr;
	int n, m = 0;
	queue<int> q;

	dinic(int n) : n(n), adj(n), lvl(n), ptr(n) {}

	void addEdge(int i, int j, ll c) {
		e.push_back({j, c, 0});
		e.push_back({i, 0, 0});
		adj[i].push_back(m++);
		adj[j].push_back(m++);
	}

	bool bfs(int s, int t) {
		fill(lvl.begin(), lvl.end(), -1);
		lvl[s] = 0;
		q.push(s);
		while (!q.empty()) {
			int v = q.front(); q.pop();
			for (int i : adj[v])
				if (e[i].c != e[i].f && lvl[e[i].j] == -1) {
					lvl[e[i].j] = lvl[v] + 1;
					q.push(e[i].j);
				}
		}
		return lvl[t] != -1;
	}

	ll dfs(int v, int t, ll push) {
		if (push == 0 || v == t)
			return push;
		for (int& idx = ptr[v]; idx < (int)adj[v].size(); idx++) {
			int id = adj[v][idx];
			if (lvl[v] + 1 != lvl[e[id].j] || e[id].c == e[id].f)
				continue;
			ll f = dfs(e[id].j, t, min(push, e[id].c - e[id].f));
			if (f != 0) {
				e[id].f += f;
				e[id ^ 1].f -= f;
				return f;
			}
		}
		return 0;
	}

	ll maxFlow(int s, int t) {
		ll ret = 0;
		while (bfs(s, t)) {
			fill(ptr.begin(), ptr.end(), 0);
			while (ll f = dfs(s, t, flow_inf))
				ret += f;
		}
		return ret;
	}
};
// copied from TUM cheat sheet
// ---------------------------

int main()
{
	int n; cin >> n;
	map<Point,int> ids;
	vector<Point> points;
	for (int i = 0; i < n; ++i)
	{
		int x1,y1,x2,y2;
		cin >> x1 >> y1 >> x2 >> y2;
		Point p1 {x1,y1}; Point p2 {x2,y2};
		points.push_back(p1); points.push_back(p2);
		ids[p1] = i; ids[p2] = n+i;
		if ((x1 + y1) % 2) swap(ids[p1],ids[p2]);	
	}
	dinic g(2*n+2);
	for (auto &[p,id] : ids)
	{
		if (id >= n) continue;
		for (int dx = -1; dx <= 1; dx++)
		{
			for (int dy = -1; dy <= 1; dy++)
			{
				Point q {p.first + dx, p.second + dy};
				if (abs(dx) != abs(dy) && ids.count(q) && id != ids[q] - n) 
					g.addEdge(id,ids[q],1);
			}
		}
	}
	for (int i = 0; i < n; ++i)
	{
		g.addEdge(2*n,i,1);
		g.addEdge(n+i,2*n+1,1);
	}
	int cnt = g.maxFlow(2*n,2*n+1);
	vector<int> match(2*n,-1);
	for (int i = 0; i < 2*n; ++i) for (int k : g.adj[i]) 
	{
		int to = g.e[k].j;
		int f = g.e[k].f;
		if (to < 2*n && f == 1)
		{
			match[i] = to;
			match[to] = i;
		}
	}
	if (cnt < n)
		cout << "impossible" << endl;
	else
	{
		for (int i = 0; i < points.size(); ++i)
		{
			Point &p = points[i];
			if (ids[p] < n) cout << ids[p];
			else cout << match[ids[p]];
			if (i % 2) cout << endl;
			else cout << " ";
		}
	}
}

